@@ -28,7 +28,7 @@ from mkdocs_include_markdown_plugin.files_watcher import FilesWatcher
 from mkdocs_include_markdown_plugin.logger import logger
 
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from typing import Literal, TypedDict
 
     from mkdocs.structure.pages import Page
@@ -630,8 +630,8 @@ def on_page_markdown(
         page.file.abs_src_path,
         docs_dir,
         {
-            'include': plugin._include_tag,
-            'include-markdown': plugin._include_markdown_tag,
+            'include': plugin._include_tag(),
+            'include-markdown': plugin._include_markdown_tag(),
         },
         {
             'encoding': config.encoding,
