@@ -11,7 +11,7 @@ from mkdocs.livereload import LiveReloadServer
 from mkdocs.plugins import BasePlugin, event_priority
 
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     import re
 
     from mkdocs.config.defaults import MkDocsConfig
@@ -46,14 +46,12 @@ class IncludeMarkdownPlugin(BasePlugin[PluginConfig]):
 
         return config
 
-    @cached_property
     def _include_tag(self) -> re.Pattern[str]:
         return create_include_tag(
             self.config.opening_tag,
             self.config.closing_tag,
         )
 
-    @cached_property
     def _include_markdown_tag(self) -> re.Pattern[str]:
         return create_include_tag(
             self.config.opening_tag,
